==> magic-7.2.68.tar.bz2: magic-7.2.68/graphics/wind3d.h <==
/*
 * wind3d.h --
 *
 *	Interface definitions for the 'glue' between the window
 *	manager and the 3D rendering window
 *
 * Copyright 2003 Open Circuit Design, Inc., for MultiGiG Ltd.
 *
 */

#define _WIND3D

#ifndef _MAGIC
    err0 = Need_to_include_misc/magic_header;
#endif	/* _MAGIC */
#ifndef	_GEOMETRY
    err1 = Need_to_include_utils/geometry_header;
#endif	/* _GEOMETRY */
#ifndef _WINDOWS
    err2 = Need_to_include_windows/windows_header;
#endif	/* _WINDOWS */

/* Data structures */

typedef struct
{
    float	view_x;		/* View angle around x axis */
    float	view_y;		/* View angle around y axis */
    float	view_z;		/* View angle around z axis */

    float	trans_x;	/* Translation in x */
    float	trans_y;	/* Translation in y */
    float	trans_z;	/* Translation in z */

    float	scale_xy;	/* Size scaling */
    float	prescale_z;	/* Depth scaling */
    float	scale_z;	/* Depth scaling */

    int		width;		/* Window width */
    int		height;		/* Window height */

    int		level;		/* rendering level (0 = coarse) */

    bool	cif;		/* If TRUE, draw CIF layers */

    bool	clipped;	/* If TRUE, set clipping */
    Rect	cutbox;		/* Clip to this box, if clipping is set */

    TileTypeBitMask visible;	/* Layers to see */

    MagWindow	*boxWin;	/* Render what's in this window */
} W3DclientRec;

/* Exported procedures */

extern void w3dSetProjection();
extern int W3Dcommand();

/* Command procedures */

extern Void w3dView();
extern Void w3dScroll();
extern Void w3dZoom();
extern Void w3dRefresh();
extern Void w3dToggleCIF();
extern Void w3dDefaults();
extern Void w3dLevel();
extern Void w3dClose();
extern Void w3dRenderValues();
extern Void w3dSeeLayers();
extern Void w3dHelp();
extern Void w3dCutBox();

extern WindClient W3DclientID;

==> magic-7.3.11.tar.bz2: magic-7.3.11/graphics/wind3d.h <==
/*
 * wind3d.h --
 *
 *	Interface definitions for the 'glue' between the window
 *	manager and the 3D rendering window
 *
 * Copyright 2003 Open Circuit Design, Inc., for MultiGiG Ltd.
 *
 */

#define _WIND3D

#ifndef _MAGIC
    err0 = Need_to_include_misc/magic_header;
#endif	/* _MAGIC */
#ifndef	_GEOMETRY
    err1 = Need_to_include_utils/geometry_header;
#endif	/* _GEOMETRY */
#ifndef _WINDOWS
    err2 = Need_to_include_windows/windows_header;
#endif	/* _WINDOWS */

/* Data structures */

typedef struct
{
    float	view_x;		/* View angle around x axis */
    float	view_y;		/* View angle around y axis */
    float	view_z;		/* View angle around z axis */

    float	trans_x;	/* Translation in x */
    float	trans_y;	/* Translation in y */
    float	trans_z;	/* Translation in z */

    float	scale_xy;	/* Size scaling */
    float	prescale_z;	/* Depth scaling */
    float	scale_z;	/* Depth scaling */

    int		width;		/* Window width */
    int		height;		/* Window height */

    int		level;		/* rendering level (0 = coarse) */

    bool	cif;		/* If TRUE, draw CIF layers */

    bool	clipped;	/* If TRUE, set clipping */
    Rect	cutbox;		/* Clip to this box, if clipping is set */

    TileTypeBitMask visible;	/* Layers to see */

    MagWindow	*boxWin;	/* Render what's in this window */
} W3DclientRec;

/* Exported procedures */

extern void w3dSetProjection();
extern void W3Dcommand();
extern void W3Dinit();

/* Command procedures */

extern void w3dView();
extern void w3dScroll();
extern void w3dZoom();
extern void w3dRefresh();
extern void w3dToggleCIF();
extern void w3dDefaults();
extern void w3dLevel();
extern void w3dClose();
extern void w3dRenderValues();
extern void w3dSeeLayers();
extern void w3dHelp();
extern void w3dCutBox();

extern WindClient W3DclientID;
